FlashStorageError

Enum FlashStorageError 

#[non_exhaustive]
pub enum FlashStorageError { IoError, IoTimeout, CantUnlock, NotAligned, OutOfBounds, NotSupported, OtherCoreRunning, Other(i32), }
Flash storage error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IoError

I/O error.



IoTimeout

I/O operation timed out.



CantUnlock

Flash could not be unlocked for writing.



NotAligned

Address or length not aligned to required boundary.



OutOfBounds

Address or length out of bounds.



NotSupported

Operation not supported (e.g. no free MMU entry).



OtherCoreRunning

Cannot write to flash as more than one core is running. Either manually suspend the other core, or use one of the available strategies:



Other(i32)

Other error with the given error code.